diff --git a/web/pgadmin/__init__.py b/web/pgadmin/__init__.py
index 32bf3358b..08e21801e 100644
--- a/web/pgadmin/__init__.py
+++ b/web/pgadmin/__init__.py
@@ -519,10 +519,7 @@ def create_app(app_name=None):
                         pass
         else:
             # We use the postgres-winreg.ini file on non-Windows
-            try:
-                from configparser import ConfigParser
-            except ImportError:
-                from ConfigParser import ConfigParser  # Python 2
+            from configparser import ConfigParser
 
             registry = ConfigParser()
 
diff --git a/web/pgadmin/authenticate/ldap.py b/web/pgadmin/authenticate/ldap.py
index edd3af612..9865f119a 100644
--- a/web/pgadmin/authenticate/ldap.py
+++ b/web/pgadmin/authenticate/ldap.py
@@ -16,17 +16,13 @@ from ldap3.core.exceptions import LDAPSocketOpenError, LDAPBindError,\
     LDAPInvalidScopeError, LDAPAttributeError, LDAPInvalidFilterError,\
     LDAPStartTLSError, LDAPSSLConfigurationError
 from flask_babelex import gettext
+from urllib.parse import urlparse
 
 from .internal import BaseAuthentication
 from pgadmin.model import User, ServerGroup, db, Role
 from flask import current_app
 from pgadmin.tools.user_management import create_user
 
-try:
-    from urllib.parse import urlparse
-except ImportError:
-    from urlparse import urlparse
-
 
 ERROR_SEARCHING_LDAP_DIRECTORY = "Error searching the LDAP directory: {}"
 
diff --git a/web/pgadmin/tools/grant_wizard/__init__.py b/web/pgadmin/tools/grant_wizard/__init__.py
index 997f4fbb1..ff4788bca 100644
--- a/web/pgadmin/tools/grant_wizard/__init__.py
+++ b/web/pgadmin/tools/grant_wizard/__init__.py
@@ -14,6 +14,8 @@ from flask import Response, url_for
 from flask import render_template, request, current_app
 from flask_babelex import gettext
 from flask_security import login_required
+from urllib.parse import unquote
+
 from pgadmin.browser.server_groups.servers.utils import parse_priv_to_db
 from pgadmin.utils import PgAdminModule
 from pgadmin.utils.ajax import make_response as ajax_response, \
@@ -21,11 +23,6 @@ from pgadmin.utils.ajax import make_response as ajax_response, \
 from pgadmin.utils.driver import get_driver
 
 from config import PG_DEFAULT_DRIVER
-
-try:
-    from urllib import unquote
-except ImportError:
-    from urllib.parse import unquote
 from pgadmin.utils.ajax import precondition_required
 from functools import wraps
 from pgadmin.utils.preferences import Preferences
diff --git a/web/pgadmin/tools/sqleditor/__init__.py b/web/pgadmin/tools/sqleditor/__init__.py
index 3e98ed3f6..c68dd66df 100644
--- a/web/pgadmin/tools/sqleditor/__init__.py
+++ b/web/pgadmin/tools/sqleditor/__init__.py
@@ -18,6 +18,7 @@ from flask import Response, url_for, render_template, session, request, \
     current_app
 from flask_babelex import gettext
 from flask_security import login_required, current_user
+from urllib.parse import unquote
 
 from config import PG_DEFAULT_DRIVER, ON_DEMAND_RECORD_COUNT
 from pgadmin.misc.file_manager import Filemanager
@@ -46,12 +47,6 @@ from pgadmin.tools.sqleditor.utils.query_history import QueryHistory
 
 MODULE_NAME = 'sqleditor'
 
-# import unquote from urllib for python2.x and python3.x
-try:
-    from urllib import unquote
-except ImportError:
-    from urllib.parse import unquote
-
 
 class SqlEditorModule(PgAdminModule):
     """
diff --git a/web/pgadmin/tools/sqleditor/command.py b/web/pgadmin/tools/sqleditor/command.py
index 3a3abf157..4df1ef901 100644
--- a/web/pgadmin/tools/sqleditor/command.py
+++ b/web/pgadmin/tools/sqleditor/command.py
@@ -10,10 +10,7 @@
 """ Implemented classes for the different object type used by data grid """
 
 from abc import ABCMeta, abstractmethod
-try:
-    from collections import OrderedDict
-except ImportError:
-    from ordereddict import OrderedDict
+from collections import OrderedDict
 import six
 from flask import render_template
 from flask_babelex import gettext
diff --git a/web/pgadmin/tools/sqleditor/tests/test_view_data_templates.py b/web/pgadmin/tools/sqleditor/tests/test_view_data_templates.py
index cf76cd7b2..c57c0e241 100644
--- a/web/pgadmin/tools/sqleditor/tests/test_view_data_templates.py
+++ b/web/pgadmin/tools/sqleditor/tests/test_view_data_templates.py
@@ -12,15 +12,12 @@ import re
 
 from flask import Flask, render_template
 from jinja2 import FileSystemLoader
+from collections import OrderedDict
 
 from pgadmin import VersionedTemplateLoader
 from pgadmin.utils.route import BaseTestGenerator
 from pgadmin.utils.driver import get_driver
 from config import PG_DEFAULT_DRIVER
-try:
-    from collections import OrderedDict
-except ImportError:
-    from ordereddict import OrderedDict
 
 
 class TestViewDataTemplates(BaseTestGenerator):
diff --git a/web/pgadmin/tools/sqleditor/utils/is_query_resultset_updatable.py b/web/pgadmin/tools/sqleditor/utils/is_query_resultset_updatable.py
index 697a4f2bb..453b3f641 100644
--- a/web/pgadmin/tools/sqleditor/utils/is_query_resultset_updatable.py
+++ b/web/pgadmin/tools/sqleditor/utils/is_query_resultset_updatable.py
@@ -23,10 +23,8 @@
 """
 from flask import render_template
 from flask_babelex import gettext
-try:
-    from collections import OrderedDict
-except ImportError:
-    from ordereddict import OrderedDict
+from collections import OrderedDict
+
 from pgadmin.tools.sqleditor.utils.get_column_types import get_columns_types
 
 
diff --git a/web/pgadmin/tools/sqleditor/utils/save_changed_data.py b/web/pgadmin/tools/sqleditor/utils/save_changed_data.py
index 9bb68a398..109391882 100644
--- a/web/pgadmin/tools/sqleditor/utils/save_changed_data.py
+++ b/web/pgadmin/tools/sqleditor/utils/save_changed_data.py
@@ -8,11 +8,9 @@
 ##########################################################################
 
 from flask import render_template
+from collections import OrderedDict
+
 from pgadmin.tools.sqleditor.utils.constant_definition import TX_STATUS_IDLE
-try:
-    from collections import OrderedDict
-except ImportError:
-    from ordereddict import OrderedDict
 
 
 def save_changed_data(changed_data, columns_info, conn, command_obj,
diff --git a/web/pgadmin/utils/driver/psycopg2/cursor.py b/web/pgadmin/utils/driver/psycopg2/cursor.py
index 532f5d3aa..af20ce2c3 100644
--- a/web/pgadmin/utils/driver/psycopg2/cursor.py
+++ b/web/pgadmin/utils/driver/psycopg2/cursor.py
@@ -13,13 +13,9 @@ fetching results from it, and also takes care of the duplicate column name in
 result.
 """
 
-try:
-    from collections import OrderedDict
-except ImportError:
-    from ordereddict import OrderedDict
 
+from collections import OrderedDict
 import psycopg2
-
 from psycopg2.extensions import cursor as _cursor, encodings
 from .encoding import configureDriverEncodings
 
diff --git a/web/pgadmin/utils/session.py b/web/pgadmin/utils/session.py
index 72a086c02..f3729cf28 100644
--- a/web/pgadmin/utils/session.py
+++ b/web/pgadmin/utils/session.py
@@ -28,21 +28,15 @@ from uuid import uuid4
 from threading import Lock
 from flask import current_app, request, flash, redirect
 from flask_login import login_url
-from pgadmin.utils.ajax import make_json_response
-
-try:
-    from cPickle import dump, load
-except ImportError:
-    from pickle import dump, load
 
-try:
-    from collections import OrderedDict
-except ImportError:
-    from ordereddict import OrderedDict
+from pickle import dump, load
+from collections import OrderedDict
 
 from flask.sessions import SessionInterface, SessionMixin
 from werkzeug.datastructures import CallbackDict
 
+from pgadmin.utils.ajax import make_json_response
+
 
 def _calc_hmac(body, secret):
     return base64.b64encode(
